@@ -34,7 +34,6 @@ pub use error::Error;
 pub use options::Options;
 
 use iron::Iron;
-use std::io::stderr;
 use std::process::exit;
 use std::sync::{Arc, Mutex, Condvar};
 use hyper_native_tls::NativeTlsServer;
@@ -47,8 +46,8 @@ fn main() {
 
 fn actual_main() -> i32 {
     if let Err(err) = result_main() {
-        err.print_error(&mut stderr());
-        err.exit_value()
+        eprintln!("{}", err);
+        1
     } else {
         0
     }
@@ -66,21 +65,21 @@ fn result_main() -> Result<(), Error> {
     let mut responder = try!(if let Some(p) = opts.port {
         if let Some(&((ref id, _), ref pw)) = opts.tls_data.as_ref() {
                 Iron::new(ops::HttpHandler::new(&opts)).https(("0.0.0.0", p),
-                                                              try!(NativeTlsServer::new(id, pw).map_err(|_| {
-                    Error::Io {
+                                                              try!(NativeTlsServer::new(id, pw).map_err(|err| {
+                    Error {
                         desc: "TLS certificate",
                         op: "open",
-                        more: None,
+                        more: err.to_string().into(),
                     }
                 })))
             } else {
                 Iron::new(ops::HttpHandler::new(&opts)).http(("0.0.0.0", p))
             }
             .map_err(|_| {
-                Error::Io {
+                Error {
                     desc: "server",
                     op: "start",
-                    more: Some("port taken".into()),
+                    more: "port taken".into(),
                 }
             })
     } else {
